==> haskell-pem-0.2.4-331-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pem
version:              0.2.4
visibility:           public
id:                   pem-0.2.4-BCVk3Mfj5wDE48d0WcD5vE
key:                  pem-0.2.4-BCVk3Mfj5wDE48d0WcD5vE
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-pem
synopsis:             Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description

category:             Data
abi:                  1940f3b1ca75a7b03eadfc21fb930bec
exposed:              True
exposed-modules:      Data.PEM
hidden-modules:       Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pem-0.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pem-0.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pem
hs-libraries:         HSpem-0.2.4-BCVk3Mfj5wDE48d0WcD5vE
depends:
    base-4.17.2.1 basement-0.0.16-6gl6nPF7HiTCe5hoNBpAx7
    bytestring-0.11.5.3 memory-0.18.0-1oHOZXUPjWrG0kImkORGvt

haddock-interfaces:   /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html:         /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pem-0.2.4-332-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pem
version:              0.2.4
visibility:           public
id:                   pem-0.2.4-FGmtS195LYlA9UUKib0eBZ
key:                  pem-0.2.4-FGmtS195LYlA9UUKib0eBZ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-pem
synopsis:             Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description

category:             Data
abi:                  ceb8d44b753e4a2ff834c523d0a0d11d
exposed:              True
exposed-modules:      Data.PEM
hidden-modules:       Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pem-0.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pem-0.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pem
hs-libraries:         HSpem-0.2.4-FGmtS195LYlA9UUKib0eBZ
depends:
    base-4.17.2.1 basement-0.0.16-6gl6nPF7HiTCe5hoNBpAx7
    bytestring-0.11.5.3 memory-0.18.0-1oHOZXUPjWrG0kImkORGvt

haddock-interfaces:   /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html:         /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
